
# Tcmd 

### About 
Tcmd stands for top commands. This tool can be used to see the most used commands. The tool was written in python3 and is pretty simple. It can be downloaded from pypi. 


### Requirements
- works on windows , linux and macOS (tested on **Debian**)
- python3 (Tcmd written in python3)
- pip (Installation is done via pip)
- python module **rich**, is installed automatically (if it wasnt found use *pip install rich*)


### Installation
```sh
pip install tcmd
```
Or  *with pip3*
```sh
pip3 install tcmd
```

#### Use / Demo

Command : 
```sh
tcmd
```
Output : 

<img src="https://cdn.discordapp.com/attachments/951417646191083551/1115161846052298834/image.png">
